type Choice<T> = {
    title: string;
    description?: string;
    value: T;
    disabled?: boolean;
};
type List<T> = (T | Choice<T>)[];
type Option<T extends Type, U> = T extends 'confirm' ? OptionConfirm : T extends 'number' ? OptionNumber : T extends 'auto' | 'multi' | 'select' ? OptionSelect<U> : T extends 'text' ? OptionText : T extends 'toggle' ? OptionToggle : never;
type OptionConfirm = OptionGeneral & {
    type: 'confirm';
    default?: boolean;
};
type OptionGeneral = {
    type: Type;
    id?: string;
    message?: string;
};
type OptionNumber = OptionGeneral & {
    type: 'number';
    default?: number;
    max: number;
    min: number;
};
type OptionSelect<T> = OptionGeneral & {
    type: 'auto' | 'multi' | 'select';
    default?: number | string;
    list: List<T>;
};
type OptionText = OptionGeneral & {
    type: 'text';
    default?: string;
};
type OptionToggle = OptionGeneral & {
    type: 'toggle';
    default?: boolean;
    off?: string;
    on?: string;
};
type Result<T extends Type = Type, U = unknown> = T extends 'confirm' ? boolean : T extends 'number' ? number : T extends 'auto' | 'multi' | 'select' ? U : T extends 'text' ? string : T extends 'toggle' ? boolean : never;
type Type = (typeof listType)[number];
declare const listType: readonly ["auto", "confirm", "multi", "number", "select", "text", "toggle"];
/**
 * Prompt the user.
 * @param option The option.
 * @returns The result.
 * @example
 * ```
 * // confirm
 * const result = await prompt({
 *   type: 'confirm',
 *   message: 'Are you sure?',
 * })
 *
 * // number
 * const result = await prompt({
 *   type: 'number',
 *   message: 'Enter a number:',
 *   min: 1,
 *   max: 10,
 * })
 *
 * // auto, multi, select
 * const result = await prompt({
 *   type: 'auto',
 *   message: 'Select a fruit:',
 *   list: ['Apple', 'Banana', 'Cherry'],
 * })
 *
 * const result = await prompt({
 *   type: 'multi',
 *   message: 'Select fruits:',
 *   list: ['Apple', 'Banana', 'Cherry'],
 * })
 *
 * const result = await prompt({
 *   type: 'select',
 *   message: 'Select a fruit:',
 *   list: ['Apple', 'Banana', 'Cherry'],
 * })
 *
 * // text
 * const result = await prompt({
 *   type: 'text',
 *   message: 'Enter your name:',
 * })
 *
 * // toggle
 * const result = await prompt({
 *   type: 'toggle',
 *   message: 'Enable feature?',
 * })
 * ```
 */
declare const main: <T, U extends "number" | "auto" | "confirm" | "multi" | "select" | "text" | "toggle" = "number" | "auto" | "confirm" | "multi" | "select" | "text" | "toggle">(option: Option<U, T> & {
    list?: List<T>;
    type: U;
}) => Promise<T & Result<U, T>>;
export { main as default };
